@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.279 2015/08/04 15:28:36 sthen Exp $
+# $OpenBSD: Quirks.pm,v 1.362 2016/02/04 12:34:48 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -77,7 +77,6 @@ my $base_exceptions = {
 	'p5-Module-CoreList' => "$p5/Module/CoreList.pm",
 	'p5-Module-Load' => "$p5/Module/Load.pm",
 	'p5-Module-Loaded' => "$p5/Module/Loaded.pm",
-	'p5-Module-Pluggable' => "$p5/Module/Pluggable.pm",
 	'p5-Time-Piece' => "$p5a/Time/Piece.pm",
 	'p5-Digest-SHA' => "$p5a/Digest/SHA.pm",
 	'p5-Pod-Escapes' => "$p5/Escapes.pm",
@@ -100,6 +99,7 @@ my $base_exceptions = {
 	'p5-IO-Socket-IP' => "$p5/IO/Socket/IP.pm",
 # 5.8
 	'libepoxy' => '/usr/X11R6/lib/libepoxy.so.1.0',
+	'flex' => '/usr/bin/flex',
 };
 
 my $stem_extensions = {
@@ -375,19 +375,29 @@ my $stem_extensions = {
 	'ruby21-passenger-standalone' => 'ruby21-passenger',
 	'ruby22-passenger-standalone' => 'ruby22-passenger',
 	'mirall' => 'owncloudclient',
+# 5.9
+	'consolekit' => 'consolekit2',
+	'tint' => 'tint2',
+	'py-nmap' => 'py3-nmap',
+	'pudb' => 'py-pudb',
+	'openexr-ctl' => 'ctl',
+	'nimrod' => 'nim',
+	'icinga2-mysql' => 'icinga2-ido-mysql',
+	'icinga2-pgsql' => 'icinga2-ido-pgsql',
+	'rcsparse' => 'py-rcsparse',
+	'tesseract-dan-frak' => 'tesseract-dan_frak',
+	'grive' => 'grive2',
+	'py-reportlab-renderPM' => 'py-reportlab',
+	'cmus-flac' => 'cmus',
+	'cmus-wavpack' => 'cmus',
+	'quake2' => 'yquake2',
+	'apertium-es-an' => 'apertium-spa-arg',
+	'apertium-nn-nb' => 'apertium-nno-nob',
+	'weblint' => 'p5-HTML-Lint',
+	'py-fabric' => 'fabric',
 };
 
 # reasons for obsolete packages
-my @msg = (
-	"ancient software that doesn't work", #0
-	"web application with no benefit being packaged", #1
-	"no longer maintained and full of security holes", #2
-	"no longer maintained upstream", #3
-	"superseded by base component", #4
-	"outdated and/or no longer required by other ports", #5
-	"no longer useful", #6
-);
-
 my $obsolete_reason = {
 	'BitTorrent' => 0,
 	'BitTorrent-gui' => 0,
@@ -505,7 +515,6 @@ my $obsolete_reason = {
 	'erl-webmachine' => 0,
 	'commons-io' => 2,
 	'qt4-qtsolutions-singleinstance' => 3,
-	'hs-cgi' => 5,
 	'hs-HsParrot' => 5,
 	'hs-HsSyck' => 5,
 	'hs-MetaObject' => 5,
@@ -596,8 +605,145 @@ my $obsolete_reason = {
 	'tla' => 3,
 	'googlecl' => 3,
 	'cyphertite' => 3,
+	'cxxtools' => 5,
+	'tntnet' => 6,
+	'dwb' => 6,
+	'ns4' => 3,
+	'tcplist' => 0,
+	'wide-dhcp' => 0,
+	'cfs' => 0,
+	'rubinius' => 5,
+	'xorp' => 5,
+	'faac' => 6,
+	'god' => 5,
+	'ivan' => 3,
+	'hs-xhtml-combinators' => 5,
+	'feldspar-compiler' => 5,
+	'feldspar-language' => 5,
+	'hs-MonadCatchIO-mtl' => 5,
+	'hs-MonadCatchIO-transformers' => 5,
+	'hs-QuickAnnotate' => 5,
+	'hs-clientsession' => 5,
+	'hs-comonad' => 5,
+	'hs-comonad-transformers' => 5,
+	'hs-comonads-fd' => 5,
+	'hs-contravariant' => 5,
+	'hs-cprng-aes' => 5,
+	'hs-data-lens' => 5,
+	'hs-data-lens-template' => 5,
+	'hs-distributive' => 5,
+	'hs-either' => 5,
+	'hs-errors' => 5,
+	'hs-ghc-mtl' => 5,
+	'hs-hint' => 5,
+	'hs-iteratee' => 5,
+	'hs-lens' => 5,
+	'hs-monads-tf' => 5,
+	'hs-semigroupoids' => 5,
+	'hs-syntactic' => 5,
+	'hs-type-level' => 5,
+	'hs-vector-algorithms' => 5,
+	'hs-ListLike' => 5,
+	'hs-atom' => 5,
+	'gstreamermm' => 3,
+	'opencm' => 3,
+	'libglademm' => 3,
+	'hs-zlib-enum' => 5,
+	'hs-blaze-builder-enumerator' => 5,
+	'hs-monad-par' => 5,
+	'hs-monad-par-extras' => 5,
+	'swfdec-plugin' => 3,
+	'yui' => 2,
+	'yui-docs' => 2,
+	'tkrat' => 3,
+	'bustle' => 5,
+	'bluetile' => 5,
+	'hs-cairo' => 5,
+	'hs-gio' => 5,
+	'hs-glade' => 5,
+	'hs-glib' => 5,
+	'hs-gtk' => 5,
+	'hs-pango' => 5,
+	'hs-webkit' => 5,
+	'node-pg' => 7,
+	'node-sqlite3' => 7,
+	'node-async' => 7,
+	'node-bindings' => 7,
+	'node-buffer-writer' => 7,
+	'node-cloned' => 7,
+	'node-expresso' => 7,
+	'node-fibers' => 7,
+	'node-generic-pool' => 7,
+	'node-gir' => 7,
+	'node-mnm' => 7,
+	'node-canvas' => 7,
+	'node-java' => 7,
+	'node-typescript' => 7,
+	'node-bcrypt' => 7,
+	'node-always' => 7,
+	'node-daemon' => 7,
+	'node-rmdir' => 7,
+	'node-syslog' => 7,
+	'gtk2hs-buildtools' => 5,
+	'coffeescript' => 7,
+	'pb-browser' => 0,
+	'unace' => 0,
+	'edict' => 3,
+	'ADMsmb' => 6,
+	'mrtd' => 3,
+	'openobex' => 6,
+	'obexftp' => 6,
+	'py-openbsd' => 3,
+	'antisniff' => 3,
+	'WebGUI' => 2,
+	'tinyca2' => 3,
+	'kxmleditor' => 3,
+	'hs-hashed-storage' => 5,
+	'gnome-common' => 3,
+	'emacs-haskell' => 7,
+	'statusnet' => 1,
+	'p5-Goo-Canvas' => 6,
+	'hs-blaze-builder-conduit' => 3,
+	'hs-network-conduit' => 3,
+	'hs-http-attoparsec' => 5,
+	'hs-shellish' => 5,
+	'hs-xmlhtml' => 5,
+	'hs-blaze-html' => 5,
+	'hs-blaze-markup' => 5,
+	'zsnes' => 2,
+	'its4' => 3,
+	'august' => 3,
+	'hs-hlint' => 7,
+	'monodevelop' => 5,
+	'hs-hoogle' => 7,
+	'hs-configurator' => 5,
+	'hs-safe' => 5,
+	'hs-uniplate' => 5,
+	'hs-vault' => 5,
+	'hs-haskell-src-exts' => 5,
+	'hs-tagsoup' => 5,
+	'hs-http-types' => 5,
+	'hs-wai' => 5,
+	'hs-warp' => 5,
+	'hs-hackage-db' => 5,
+	'c2hs' => 5,
+	'hs-language-c' => 5,
+	'hs-simple-sendfile' => 5,
+	'monadius' => 3,
+	'hs-bimap' => 5,
 };
 
+my @msg = (
+	"ancient software that doesn't work", #0
+	"web application with no benefit being packaged", #1
+	"no longer maintained and full of security holes", #2
+	"no longer maintained upstream", #3
+	"superseded by base component", #4
+	"outdated and/or no longer required by other ports", #5
+	"no longer useful", #6
+	"removed in favor of using languages package manager", #7
+);
+
 # ->is_base_system($handle, $state):
 #	checks whether an existing handle is now part of the base system
 #	and thus no longer needed.
@@ -691,6 +837,8 @@ my $cve = {
 	'audio/flac' => 'flac-<1.3.0p1',
 	'www/drupal6/views' => 'drupal6-views-<2.18',
 	'graphics/tiff' => 'tiff-<4.0.4beta',
+	'net/lldpd' => 'lldpd-<0.7.18p0',
+	'devel/pcre' => 'pcre-<8.38',
 };
 
 # ->check_security($path)
